USCA6 Opinions List

CA6 Home

Opinions in the cases listed below were filed by the U.S. Court of Appeals for the Sixth Circuit:
PUBLISHED OPINIONS

Opinion | DocketSheet | Pub Date | Short Title/District
--- | --- | --- | ---
12a0053p.06 | 10-3590 | 2012/02/24 | Dion Berryman v. SuperValu Holdings, Inc. Southern District of Ohio at Dayton
12a0054p.06 | 10-3092 | 2012/02/24 | USA v. Thomas Cunningham Northern District of Ohio at Cleveland

NOT RECOMMENDED FOR FULL-TEXT PUBLICATION OPINIONS
NOTE: The "Filed" date for an unpublished opinion is not always the date on which it is posted.
Please check the opinion for the correct filed date.

Opinion | DocketSheet | Pub Date | Short Title/District
--- | --- | --- | ---
12a0220n.06 | 08-2269 | 2012/02/24 | Benjamin McCoy v. Kurt Jones Eastern District of Michigan at Detroit
12a0221n.06 | 10-4528 | 2012/02/24 | Jamie Ratliff v. Commissioner of Social Security Northern District of Ohio at Cleveland
12a0222n.06 | 10-6059 | 2012/02/24 | USA v. Gary Fleming Eastern District of Tennessee at Winchester
12a0223n.06 | 10-6107 | 2012/02/24 | USA v. Paul Marriott Eastern District of Tennessee at Greeneville
12a0224n.06 | 10-6559 | 2012/02/24 | USA v. Donnie Justice Eastern District of Kentucky at Covington